#!/bin/bash

# modify the paths to match the location of your own script and xabatch file
# protect this script and the xabatch file (this can be done at the end of the
# script as well, right before the reboot command)

chown 0:80 ~/Library/Scripts/Unix/beforeReboot.sh
chmod 0550 ~/Library/Scripts/Unix/beforeReboot.sh
chown 0:80 ~/Library/Scripts/Unix/apple.XAs.xabatch
chmod 0440 ~/Library/Scripts/Unix/apple.XAs.xabatch

# this can be omitted if you don't need verbose feedback
DATE=`date '+%Y.%m.%d at %H:%M:%S.'`; say 'Cleansing started on'; say $DATE

# all 'say' lines can be removed if you don't need verbose feedback
# or you could just use the silent way if you get tired of the gimmick
# add or remove items as you see fit

say 'Step 1 of 7: Removing caches and logs...'

rm -rf /Library/Caches/* /System/Library/Caches/* /Library/Logs/* ~/Library/Caches/* ~/Library/Logs/* /private/var/log/*.log.* /private/var/log/*.log.*.bz2 /private/var/log/cups/* /private/var/log/fax/* /private/var/log/ppp/* /private/var/log/sa/* /private/var/log/samba/*

# do '/private/var/folders/*/*/-Caches-;ls -aFGhilORSTvW' and look for 'Cache.db';
# if the file size bothers you, add it to the following items
# Safari is a must, it grows really big in no time

rm -rf /private/var/folders/*/*/-Caches-/com.apple.ATS/* /private/var/folders/*/*/-Caches-/com.apple.Dictionary/* /private/var/folders/*/*/-Caches-/com.apple.dashboard.client/* /private/var/folders/*/*/-Caches-/com.apple.mail/* /private/var/folders/*/*/-Caches-/com.apple.Safari/* /private/var/folders/*/*/-Caches-/com.apple.Xcode.501/*

# these will be rebuilt immediately after reboot but it's probably a good idea to keep them on a leash
rm -rf /private/var/folders/*/*/-Caches-/com.apple.desktoppicture.* /private/var/folders/*/*/-Caches-/com.apple.dock.iconcache

say 'Step 1 completed. 6 to go.'
say 'Step 2 of 7: Emptying some logs inside /private/var/log/...'

# do '/private/var/logs; ls -aFGhilORSTvW' to see which items you have;
# add or remove items as needed

cp /dev/null /private/var/log/alf.log
cp /dev/null /private/var/log/apache2/error_log
cp /dev/null /private/var/log/apache2/access_log
cp /dev/null /private/var/log/appfirewall.log
cp /dev/null /private/var/log/asl.db
cp /dev/null /private/var/log/daily.out
cp /dev/null /private/var/log/fsck_hfs.log
cp /dev/null /private/var/log/hdiejectd.log
cp /dev/null /private/var/log/install.log
cp /dev/null /private/var/log/ipfw.log
cp /dev/null /private/var/log/mb.log
cp /dev/null /private/var/log/monthly.out
cp /dev/null /private/var/log/secure.log
cp /dev/null /private/var/log/system.log
cp /dev/null /private/var/log/weekly.out
cp /dev/null /private/var/log/windowserver.log
cp /dev/null /private/var/log/windowserver_last.log

say 'Step 2 completed. 5 to go.'
say 'Step 3 of 7: Emptying some junk inside the home directory...'

# do 'cd ~; ls -aFGhilOSTvW' and see what's in there;
# if you use Gimp you'll have things like '.recently-used.xbel' that should be kept on a leash

cp /dev/null ~/.bash_history; rm -rf ~/.thumbnails/*

say 'Step 3 completed. 4 to go.'
say 'Step 4 of 7: Removing useless localizations and designable.nibs...'

find /Applications ~/Applications /Library ~/Library \( -iname '*.lproj' -and \! \( -iname 'en*' \) -and \! \( -path '/Library/Receipts/*' -or -path '~/Library/Receipts/*' \) \) -print0 | xargs -0 rm -frv {}

# look at the example below for ways to keep other localizations you need to keep

# find /Applications ~/Applications /Library ~/Library # \( -iname '*.lproj' -and \! \( -iname 'en*' -or -iname 'ja*' \) -and \! # \( -path '/Library/Receipts/*' -or -path '~/Library/Receipts/*' \) \) -print0 | xargs -0 rm -frv {}

# if you never repair permissions, you don't need to exclude /Library/Receipts and ~/Library/Receipts
# if you don't need verbose feedback, you can omit the -v argument for rm

find /Applications ~/Applications /Library ~/Library \( -name 'designable.nib' -and \! \( -path '/Library/Receipts/*' -or -path '~/Library/Receipts/*' \) \) -type f -print0 | xargs -0 rm -frv {}

say 'Step 4 completed. 3 to go.'
say 'Step 5 of 7: Removing .DS_Store and .localized files...'

# change '~' to '/' if you want a more thorough (but time consuming) sweep

find ~ \( -name '.DS_Store' -or -name '.localized' \) -print0 | xargs -0 rm -frv {}

say 'Step 5 completed. 2 to go.'
say 'Step 6 of 7: Removing Desktop DB and Desktop DF...'

rm -f /Desktop\ DB /Desktop\ DF

say 'Step 6 completed. 1 to go.'
say 'Step 7 of 7: Removing extended attributes in the home directory...'

# modify the paths to match the location of the xabatch script (usually in ACP/etc) and xabatch file

# more info about xabatch at:
# http://rixstep.com/1/20071224,00.shtml
# http://rixstep.com/2/20080105,00.shtml

find ~ -print0 | xargs -0 ~/Applications/ACP/etc/xabatch ~/Library/Scripts/Unix/apple.XAs.xabatch {}

say 'Step 7 completed.'
DATE=`date '+%Y.%m.%d %H:%M:%S.'`; say 'Done. Cleansing completed on '; say $DATE

# Preparing to reboot

say 'Preparing to reboot. Fasten your seat belt and put your seat in an upright position.'
say 'The captain has turned on the no smoking sign.'

# if you prefer to protect the script and the xabatch file at the end,
# put the first 4 lines of the script here

reboot